<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>DimRadial</name>
    <message>
        <location filename="../DimRadial.js" line="+57"/>
        <source>Choose arc or circle entity</source>
        <translation>选择弧或圆</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Dimension line location or angle</source>
        <translation>尺寸线位置或角度</translation>
    </message>
    <message>
        <location filename="../DimRadialInit.js" line="+2"/>
        <source>&amp;Radial</source>
        <translation>半径(&amp;R)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw radial dimension</source>
        <translation>绘制半径标注</translation>
    </message>
</context>
</TS>
